Command List
============

kafka-assigner
  This script is used for performing partition
  reassignments and preferred replica elections. It uses the admin CLI
  utilities provided with Kafka and layers on additional logic to
  perform tasks like removing a broker, rebalancing partitions, fixing
  partition replcation factors, and performing preferred replica elections.
